@@ -4,7 +4,7 @@ use strict;
 no warnings;
 
 
-our $VERSION='0.03'; 
+our $VERSION='0.04'; 
 
 
 sub render {
@@ -19,7 +19,8 @@ sub render {
 
 			# $delims must be 2 element array reference
 			if ( ref($delims) and $#{$delims} == 1 ) {	
-				$template =~ s/${$delims}[0] . '\s*' . $k . '\s*' . ${$delims}[1]/${$hash_ref}{$k}/g;
+				my $r = ${$delims}[0] . '\s*' . $k . '\s*' . ${$delims}[1];
+				$template =~ s/$r/${$hash_ref}{$k}/g;
 			}
 			else {
 				$template =~ s/$k/${$hash_ref}{$k}/g;
